pub fn transfer_expendable_all<T, AccountId>(_dust_trap: Option<AccountId>)where
T: Mutate<AccountId>,
<T as Inspect<AccountId>>::Balance: AtLeast8BitUnsigned + Debug,
AccountId: AtLeast8BitUnsigned,Expand description
Test the transfer function with Preservation::Expendable for transferring the entire
balance.
This test verifies that transferring the entire balance from one account to another with
Preservation::Expendable updates the account balances and maintains the total issuance and
active issuance values.
Type Parameters
- `T`: Implements `Mutate<AccountId>`.
- `AccountId`: Account identifier implementing `AtLeast8BitUnsigned`.