pub fn transfer_protect_preserve<T, AccountId>(_dust_trap: Option<AccountId>)where
T: Mutate<AccountId>,
<T as Inspect<AccountId>>::Balance: AtLeast8BitUnsigned + Debug,
AccountId: AtLeast8BitUnsigned,Expand description
Test the transfer function with Preservation::Protect and Preservation::Preserve for
transferring the entire balance.
This test verifies that attempting to transfer the entire balance with Preservation::Protect
or Preservation::Preserve returns an error, and the account balances, total issuance, and
active issuance values remain unchanged.
Type Parameters
- `T`: Implements `Mutate<AccountId>`.
- `AccountId`: Account identifier implementing `AtLeast8BitUnsigned`.